    	    =============================================
    	    VISCII 1.1 to Unicode 1.1 (ISO 10646) MAPPING
    	    =============================================

    This document contains two segments:

        1) Code fragment of a table mapping the 256 VISCII 1.1
           character codes to Unicode 1.1.  This is the same
           as the table found in AT&T's Plan 9 TCS character set
           conversion utility, available for anonymous FTP from
           research.att.com:dist/tcs.tar.Z.

        2) Line-by-line mapping of the 134 Vietnamese-specific
           letters, from VISCII 1.1 to Unicode 1.1, including
           their VIQR mnemonic representation and the English
           character names.

    For further information, consult the VISCII documentation, or
    contact Viet-Std@Haydn.Stanford.EDU.

    ===================

    long tabviscii[256] =
    {
    0x0000, 0x0001, 0x1EB2, 0x0003, 0x0004, 0x1EB4, 0x1EAA, 0x0007,
    0x0008, 0x0009, 0x000a, 0x000b, 0x000c, 0x000d, 0x000e, 0x000f,
    0x0010, 0x0011, 0x0012, 0x0013, 0x1EF6, 0x0015, 0x0016, 0x0017,
    0x0018, 0x1EF8, 0x001a, 0x001b, 0x001c, 0x001d, 0x1EF4, 0x001f,
    0x0020, 0x0021, 0x0022, 0x0023, 0x0024, 0x0025, 0x0026, 0x0027,
    0x0028, 0x0029, 0x002a, 0x002b, 0x002c, 0x002d, 0x002e, 0x002f,
    0x0030, 0x0031, 0x0032, 0x0033, 0x0034, 0x0035, 0x0036, 0x0037,
    0x0038, 0x0039, 0x003a, 0x003b, 0x003c, 0x003d, 0x003e, 0x003f,
    0x0040, 0x0041, 0x0042, 0x0043, 0x0044, 0x0045, 0x0046, 0x0047,
    0x0048, 0x0049, 0x004a, 0x004b, 0x004c, 0x004d, 0x004e, 0x004f,
    0x0050, 0x0051, 0x0052, 0x0053, 0x0054, 0x0055, 0x0056, 0x0057,
    0x0058, 0x0059, 0x005a, 0x005b, 0x005c, 0x005d, 0x005e, 0x005f,
    0x0060, 0x0061, 0x0062, 0x0063, 0x0064, 0x0065, 0x0066, 0x0067,
    0x0068, 0x0069, 0x006a, 0x006b, 0x006c, 0x006d, 0x006e, 0x006f,
    0x0070, 0x0071, 0x0072, 0x0073, 0x0074, 0x0075, 0x0076, 0x0077,
    0x0078, 0x0079, 0x007a, 0x007b, 0x007c, 0x007d, 0x007e, 0x007f,
    0x1EA0, 0x1EAE, 0x1EB0, 0x1EB6, 0x1EA4, 0x1EA6, 0x1EA8, 0x1EAC,
    0x1EBC, 0x1EB8, 0x1EBE, 0x1EC0, 0x1EC2, 0x1EC4, 0x1EC6, 0x1ED0,
    0x1ED2, 0x1ED4, 0x1ED6, 0x1ED8, 0x1EE2, 0x1EDA, 0x1EDC, 0x1EDE,
    0x1ECA, 0x1ECE, 0x1ECC, 0x1EC8, 0x1EE6, 0x0168, 0x1EE4, 0x1EF2,
    0x00D5, 0x1EAF, 0x1EB1, 0x1EB7, 0x1EA5, 0x1EA7, 0x1EA9, 0x1EAD,
    0x1EBD, 0x1EB9, 0x1EBF, 0x1EC1, 0x1EC3, 0x1EC5, 0x1EC7, 0x1ED1,
    0x1ED3, 0x1ED5, 0x1ED7, 0x1EE0, 0x01A0, 0x1ED9, 0x1EDD, 0x1EDF,
    0x1ECB, 0x1EF0, 0x1EE8, 0x1EEA, 0x1EEC, 0x01A1, 0x1EDB, 0x01AF,
    0x00C0, 0x00C1, 0x00C2, 0x00C3, 0x1EA2, 0x0102, 0x1EB3, 0x1EB5,
    0x00C8, 0x00C9, 0x00CA, 0x1EBA, 0x00CC, 0x00CD, 0x0128, 0x1EF3,
    0x0110, 0x1EE9, 0x00D2, 0x00D3, 0x00D4, 0x1EA1, 0x1EF7, 0x1EEB,
    0x1EED, 0x00D9, 0x00DA, 0x1EF9, 0x1EF5, 0x00DD, 0x1EE1, 0x01B0,
    0x00E0, 0x00E1, 0x00E2, 0x00E3, 0x1EA3, 0x0103, 0x1EEF, 0x1EAB,
    0x00E8, 0x00E9, 0x00EA, 0x1EBB, 0x00EC, 0x00ED, 0x0129, 0x1EC9,
    0x0111, 0x1EF1, 0x00F2, 0x00F3, 0x00F4, 0x00F5, 0x1ECF, 0x1ECD,
    0x1EE5, 0x00F9, 0x00FA, 0x0169, 0x1EE7, 0x00FD, 0x1EE3, 0x1EEE
    };

    ===================

    VISCII	VIQR	UCS-2	English
    1.1	Viet	(10646)	Character
    Decimal	Letter	Hex	Name
    -------	------	-------	---------
    2	A(?	1EB2	LATIN CAPITAL LETTER A WITH BREVE AND HOOK ABOVE
    5	A(~	1EB4	LATIN CAPITAL LETTER A WITH BREVE AND TILDE
    6	A^~	1EAA	LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND TILDE
    20	Y?	1EF6	LATIN CAPITAL LETTER Y WITH HOOK ABOVE
    25	Y~	1EF8	LATIN CAPITAL LETTER Y WITH TILDE
    30	Y.	1EF4	LATIN CAPITAL LETTER Y WITH DOT BELOW
    128	A.	1EA0	LATIN CAPITAL LETTER A WITH DOT BELOW
    129	A('	1EAE	LATIN CAPITAL LETTER A WITH BREVE AND ACUTE
    130	A(`	1EB0	LATIN CAPITAL LETTER A WITH BREVE AND GRAVE
    131	A(.	1EB6	LATIN CAPITAL LETTER A WITH BREVE AND DOT BELOW
    132	A^'	1EA4	LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND ACUTE
    133	A^`	1EA6	LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND GRAVE
    134	A^?	1EA8	LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
    135	A^.	1EAC	LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND DOT BELOW
    136	E~	1EBC	LATIN CAPITAL LETTER E WITH TILDE
    137	E.	1EB8	LATIN CAPITAL LETTER E WITH DOT BELOW
    138	E^'	1EBE	LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
    139	E^`	1EC0	LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
    140	E^?	1EC2	LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
    141	E^~	1EC4	LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE
    142	E^.	1EC6	LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
    143	O^'	1ED0	LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE
    144	O^`	1ED2	LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE
    145	O^?	1ED4	LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
    146	O^~	1ED6	LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE
    147	O^.	1ED8	LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW
    148	O+.	1EE2	LATIN CAPITAL LETTER O WITH HORN AND DOT BELOW
    149	O+'	1EDA	LATIN CAPITAL LETTER O WITH HORN AND ACUTE
    150	O+`	1EDC	LATIN CAPITAL LETTER O WITH HORN AND GRAVE
    151	O+?	1EDE	LATIN CAPITAL LETTER O WITH HORN AND HOOK ABOVE
    152	I.	1ECA	LATIN CAPITAL LETTER I WITH DOT BELOW
    153	O?	1ECE	LATIN CAPITAL LETTER O WITH HOOK ABOVE
    154	O.	1ECC	LATIN CAPITAL LETTER O WITH DOT BELOW
    155	I?	1EC8	LATIN CAPITAL LETTER I WITH HOOK ABOVE
    156	U?	1EE6	LATIN CAPITAL LETTER U WITH HOOK ABOVE
    157	U~	0168	LATIN CAPITAL LETTER U WITH TILDE
    158	U.	1EE4	LATIN CAPITAL LETTER U WITH DOT BELOW
    159	Y`	1EF2	LATIN CAPITAL LETTER Y WITH GRAVE
    160	O~	00D5	LATIN CAPITAL LETTER O WITH TILDE
    161	a('	1EAF	LATIN SMALL LETTER A WITH BREVE AND ACUTE
    162	a(`	1EB1	LATIN SMALL LETTER A WITH BREVE AND GRAVE
    163	a(.	1EB7	LATIN SMALL LETTER A WITH BREVE AND DOT BELOW
    164	a^'	1EA5	LATIN SMALL LETTER A WITH CIRCUMFLEX AND ACUTE
    165	a^`	1EA7	LATIN SMALL LETTER A WITH CIRCUMFLEX AND GRAVE
    166	a^?	1EA9	LATIN SMALL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
    167	a^.	1EAD	LATIN SMALL LETTER A WITH CIRCUMFLEX AND DOT BELOW
    168	e~	1EBD	LATIN SMALL LETTER E WITH TILDE
    169	e.	1EB9	LATIN SMALL LETTER E WITH DOT BELOW
    170	e^'	1EBF	LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
    171	e^`	1EC1	LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
    172	e^?	1EC3	LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
    173	e^~	1EC5	LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE
    174	e^.	1EC7	LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
    175	o^'	1ED1	LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE
    176	o^`	1ED3	LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE
    177	o^?	1ED5	LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
    178	o^~	1ED7	LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE
    179	O+~	1EE0	LATIN CAPITAL LETTER O WITH HORN AND TILDE
    180	O+	01A0	LATIN CAPITAL LETTER O WITH HORN
    181	o^.	1ED9	LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW
    182	o+`	1EDD	LATIN SMALL LETTER O WITH HORN AND GRAVE
    183	o+?	1EDF	LATIN SMALL LETTER O WITH HORN AND HOOK ABOVE
    184	i.	1ECB	LATIN SMALL LETTER I WITH DOT BELOW
    185	U+.	1EF0	LATIN CAPITAL LETTER U WITH HORN AND DOT BELOW
    186	U+'	1EE8	LATIN CAPITAL LETTER U WITH HORN AND ACUTE
    187	U+`	1EEA	LATIN CAPITAL LETTER U WITH HORN AND GRAVE
    188	U+?	1EEC	LATIN CAPITAL LETTER U WITH HORN AND HOOK ABOVE
    189	o+	01A1	LATIN SMALL LETTER O WITH HORN
    190	o+'	1EDB	LATIN SMALL LETTER O WITH HORN AND ACUTE
    191	U+	01AF	LATIN CAPITAL LETTER U WITH HORN
    192	A`	00C0	LATIN CAPITAL LETTER A WITH GRAVE
    193	A'	00C1	LATIN CAPITAL LETTER A WITH ACUTE
    194	A^	00C2	LATIN CAPITAL LETTER A WITH CIRCUMFLEX
    195	A~	00C3	LATIN CAPITAL LETTER A WITH TILDE
    196	A?	1EA2	LATIN CAPITAL LETTER A WITH HOOK ABOVE
    197	A(	0102	LATIN CAPITAL LETTER A WITH BREVE
    198	a(?	1EB3	LATIN SMALL LETTER A WITH BREVE AND HOOK ABOVE
    199	a(~	1EB5	LATIN SMALL LETTER A WITH BREVE AND TILDE
    200	E`	00C8	LATIN CAPITAL LETTER E WITH GRAVE
    201	E'	00C9	LATIN CAPITAL LETTER E WITH ACUTE
    202	E^	00CA	LATIN CAPITAL LETTER E WITH CIRCUMFLEX
    203	E?	1EBA	LATIN CAPITAL LETTER E WITH HOOK ABOVE
    204	I`	00CC	LATIN CAPITAL LETTER I WITH GRAVE
    205	I'	00CD	LATIN CAPITAL LETTER I WITH ACUTE
    206	I~	0128	LATIN CAPITAL LETTER I WITH TILDE
    207	y`	1EF3	LATIN SMALL LETTER Y WITH GRAVE
    208	DD	0110	LATIN CAPITAL LETTER D WITH STROKE
    209	u+'	1EE9	LATIN SMALL LETTER U WITH HORN AND ACUTE
    210	O`	00D2	LATIN CAPITAL LETTER O WITH GRAVE
    211	O'	00D3	LATIN CAPITAL LETTER O WITH ACUTE
    212	O^	00D4	LATIN CAPITAL LETTER O WITH CIRCUMFLEX
    213	a.	1EA1	LATIN SMALL LETTER A WITH DOT BELOW
    214	y?	1EF7	LATIN SMALL LETTER Y WITH HOOK ABOVE
    215	u+`	1EEB	LATIN SMALL LETTER U WITH HORN AND GRAVE
    216	u+?	1EED	LATIN SMALL LETTER U WITH HORN AND HOOK ABOVE
    217	U`	00D9	LATIN CAPITAL LETTER U WITH GRAVE
    218	U'	00DA	LATIN CAPITAL LETTER U WITH ACUTE
    219	y~	1EF9	LATIN SMALL LETTER Y WITH TILDE
    220	y.	1EF5	LATIN SMALL LETTER Y WITH DOT BELOW
    221	Y'	00DD	LATIN CAPITAL LETTER Y WITH ACUTE
    222	o+~	1EE1	LATIN SMALL LETTER O WITH HORN AND TILDE
    223	u+	01B0	LATIN SMALL LETTER U WITH HORN
    224	a`	00E0	LATIN SMALL LETTER A WITH GRAVE
    225	a'	00E1	LATIN SMALL LETTER A WITH ACUTE
    226	a^	00E2	LATIN SMALL LETTER A WITH CIRCUMFLEX
    227	a~	00E3	LATIN SMALL LETTER A WITH TILDE
    228	a?	1EA3	LATIN SMALL LETTER A WITH HOOK ABOVE
    229	a(	0103	LATIN SMALL LETTER A WITH BREVE
    230	u+~	1EEF	LATIN SMALL LETTER U WITH HORN AND TILDE
    231	a^~	1EAB	LATIN SMALL LETTER A WITH CIRCUMFLEX AND TILDE
    232	e`	00E8	LATIN SMALL LETTER E WITH GRAVE
    233	e'	00E9	LATIN SMALL LETTER E WITH ACUTE
    234	e^	00EA	LATIN SMALL LETTER E WITH CIRCUMFLEX
    235	e?	1EBB	LATIN SMALL LETTER E WITH HOOK ABOVE
    236	i`	00EC	LATIN SMALL LETTER I WITH GRAVE
    237	i'	00ED	LATIN SMALL LETTER I WITH ACUTE
    238	i~	0129	LATIN SMALL LETTER I WITH TILDE
    239	i?	1EC9	LATIN SMALL LETTER I WITH HOOK ABOVE
    240	dd	0111	LATIN SMALL LETTER D WITH STROKE
    241	u+.	1EF1	LATIN SMALL LETTER U WITH HORN AND DOT BELOW
    242	o`	00F2	LATIN SMALL LETTER O WITH GRAVE
    243	o'	00F3	LATIN SMALL LETTER O WITH ACUTE
    244	o^	00F4	LATIN SMALL LETTER O WITH CIRCUMFLEX
    245	o~	00F5	LATIN SMALL LETTER O WITH TILDE
    246	o?	1ECF	LATIN SMALL LETTER O WITH HOOK ABOVE
    247	o.	1ECD	LATIN SMALL LETTER O WITH DOT BELOW
    248	u.	1EE5	LATIN SMALL LETTER U WITH DOT BELOW
    249	u`	00F9	LATIN SMALL LETTER U WITH GRAVE
    250	u'	00FA	LATIN SMALL LETTER U WITH ACUTE
    251	u~	0169	LATIN SMALL LETTER U WITH TILDE
    252	u?	1EE7	LATIN SMALL LETTER U WITH HOOK ABOVE
    253	y'	00FD	LATIN SMALL LETTER Y WITH ACUTE
    254	o+.	1EE3	LATIN SMALL LETTER O WITH HORN AND DOT BELOW
    255	U+~	1EEE	LATIN CAPITAL LETTER U WITH HORN AND TILDE